@@ -146,7 +146,7 @@ def create_department(data: dict) -> dict:
 
     # 找到最大排序数
     show_order = Department.objects.aggregate(num=Max('show_order'))["num"]
-    data["show_order"] = show_order + 1
+    data["show_order"] = show_order + 1 if show_order else 1
     data["path"] = path
     # 查询当前添加的部门同一级别是否有重复
     same_level_department = Department.objects.filter(
@@ -277,11 +277,11 @@ def add_department_user_map(organization_id: int, department_id: int, user_ids:
 
 
 # def get_department_user(organization_id: int, department_id: int, page: int, size: int):
-def get_department_user(organization_id: int, department_id: int):
+def get_department_user(organization_id: int, department_ids: list):
     """
     通过部门获取用户
     :param organization_id: 组织id
-    :param department_id: 部门id
+    :param department_ids: 部门id
     :param page: 页码
     :param size: 每页数量
     :return:
@@ -289,7 +289,7 @@ def get_department_user(organization_id: int, department_id: int):
     user_ids = DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
         department__is_deleted=False,
-        department_id=department_id
+        department_id__in=department_ids
     ).order_by("-id").values_list("user_id", flat=True)
     return Resp(data=list(user_ids))
     # total = user_ids.count()
@@ -423,6 +423,12 @@ def user_change_department(organization_id: int, user_id: int, department_ids: l
     :return:
     """
     try:
+        valid_department_count = Department.objects.filter(
+            id__in=department_ids,
+            organization_id=organization_id
+        ).count()
+        if not valid_department_count == len(department_ids):
+            raise ValueError("参数错误")
         DepartmentUserMap.objects.filter(
             department__organization_id=organization_id,
             user_id=user_id
